@@ -1,4 +1,4 @@
-// Copyright 2012-2022 The NATS Authors
+// Copyright 2012-2023 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -369,7 +369,7 @@ func TestJetStreamOrderedConsumerDeleteAssets(t *testing.T) {
 	t.Run("remove consumer, expect it to be recreated", func(t *testing.T) {
 		createStream()
 
-		createConsSub, err := nc.SubscribeSync("$JS.API.CONSUMER.CREATE.OBJECT")
+		createConsSub, err := nc.SubscribeSync("$JS.API.CONSUMER.CREATE.OBJECT.*.a")
 		if err != nil {
 			t.Fatalf("Unexpected error: %v", err)
 		}
@@ -537,20 +537,22 @@ func TestJetStreamConcurrentQueueDurablePushConsumers(t *testing.T) {
 	}
 
 	// Now create 10 durables concurrently.
-	subs := make(chan *Subscription, 10)
+	subs := make([]*Subscription, 0, 10)
 	var wg sync.WaitGroup
+	mx := &sync.Mutex{}
 
 	for i := 0; i < 10; i++ {
 		wg.Add(1)
 		go func() {
 			defer wg.Done()
 			sub, _ := js.QueueSubscribeSync("foo", "bar")
-			subs <- sub
+			mx.Lock()
+			subs = append(subs, sub)
+			mx.Unlock()
 		}()
 	}
 	// Wait for all the consumers.
 	wg.Wait()
-	close(subs)
 
 	si, err := js.StreamInfo("TEST")
 	if err != nil {
@@ -570,7 +572,7 @@ func TestJetStreamConcurrentQueueDurablePushConsumers(t *testing.T) {
 	got := 0
 	for time.Now().Before(timeout) {
 		got = 0
-		for sub := range subs {
+		for _, sub := range subs {
 			pending, _, _ := sub.Pending()
 			// If a single sub has the total, then probably something is not right.
 			if pending == total {
@@ -1206,7 +1208,10 @@ func TestJetStreamStreamInfoWithSubjectDetails(t *testing.T) {
 	// Publish on enough subjects to exercise the pagination
 	payload := make([]byte, 10)
 	for i := 0; i < 100001; i++ {
-		nc.Publish(fmt.Sprintf("test.%d", i), payload)
+		_, err := js.Publish(fmt.Sprintf("test.%d", i), payload)
+		if err != nil {
+			t.Fatalf("Unexpected error: %v", err)
+		}
 	}
 
 	// Check that passing a filter returns the subject details
